@@ -41,52 +41,58 @@ class Operation:
 
         node_count = self.node_count
 
-        dct = {
-            k: v
-            for k, v in {
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(
+            {
                 "characteristics": characteristics,
                 "name": name,
                 "parameters": parameters,
                 "sites": sites,
-                "node_count": node_count,
-            }.items()
-            if v != UNSET
-        }
+            }
+        )
+        if node_count is not UNSET:
+            field_dict["node_count"] = node_count
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "Operation":
+    def from_dict(src_dict: Dict[str, Any]) -> "Operation":
+        d = src_dict.copy()
         characteristics = []
-        _characteristics = d["characteristics"]
+        _characteristics = d.pop("characteristics")
         for characteristics_item_data in _characteristics:
             characteristics_item = Characteristic.from_dict(characteristics_item_data)
 
             characteristics.append(characteristics_item)
 
-        name = d["name"]
+        name = d.pop("name")
 
         parameters = []
-        _parameters = d["parameters"]
+        _parameters = d.pop("parameters")
         for parameters_item_data in _parameters:
             parameters_item = Parameter.from_dict(parameters_item_data)
 
             parameters.append(parameters_item)
 
         sites = []
-        _sites = d["sites"]
+        _sites = d.pop("sites")
         for sites_item_data in _sites:
             sites_item = OperationSite.from_dict(sites_item_data)
 
             sites.append(sites_item)
 
-        node_count = d.get("node_count")
+        node_count = d.pop("node_count", UNSET)
 
-        return Operation(
+        operation = Operation(
             characteristics=characteristics,
             name=name,
             parameters=parameters,
             sites=sites,
             node_count=node_count,
         )
+
+        return operation
